import { TFunction } from "i18next";
import { RegisterOptions } from "react-hook-form";
import { TranslatedString } from "./TranslatedString";
/**
 * An arbitrary value with a human-readable label.
 * To be used for selects/autocompletes/….
 */
export interface LabeledValue {
    label: string;
    value: string | number | boolean;
    /**
     * A string can be provided to indicate a reason for being disabled.
     */
    disabled?: boolean | string;
}
/**
 * An arbitrary value, a human-readable label and a group.
 * To be used for selects/autocompletes/….
 */
export interface LabeledValueWithGrouping extends LabeledValue {
    group?: string;
}
export type TranslatedValidate = (t: TFunction) => RegisterOptions["validate"];
/**
 * Generic props received by any form field.
 *
 * String values can be given as TranslatedString to faclitate having static defaults.
 */
export interface FormField {
    /**
     * The label shown to the user.
     */
    label?: string | TranslatedString;
    /**
     * The name within the react-hook-form context.
     */
    name: string;
    /**
     * T Function from i18next for translating stuff.
     */
    t?: TFunction;
    /**
     * @default false
     */
    required?: boolean;
    /**
     * Shown when the field is not filled out, but required.
     */
    requiredErrorMessage?: string | TranslatedString;
    /**
     * Custom validation function(s) for the field.
     *
     * Note: this is expected to be a function (receiving a TFunction) returning the validation function.
     *
     * @example
     * ```
     *    // validate a string input, returning a translated error message
     *    const validate = (t) => (input: string) => {
     *        if (!input) {
     *          return t("common:invalidStuff")
     *        }
     *    }
     * ```
     */
    validate?: RegisterOptions["validate"] | {
        translated: TranslatedValidate;
    } | undefined;
}
/**
 * The FormField with applied translations.
 */
export interface FormFieldTranslated extends Omit<FormField, "label" | "requiredErrorMessage" | "validate"> {
    label: string;
    requiredErrorMessage: string;
    validate: RegisterOptions["validate"] | undefined;
}
