var iconsMaterial = require('@mui/icons-material');
var material = require('@mui/material');
var baseline = require('@nvon/baseline');
var react = require('react');
var reactHookForm = require('react-hook-form');
var jsxRuntime = require('react/jsx-runtime');
var lodashEs = require('lodash-es');
var i18next = require('i18next');
var xDatePickers = require('@mui/x-date-pickers');
var dayjs = require('dayjs');
var reactNumberFormat = require('react-number-format');
var lab = require('@mui/lab');

const formContextNull = "FormContext is null. This should not happen. You may need to use the HookFormProvider instead of the FormProvider exported by react-hook-form";

const FormFieldErrorDisplay = ({
  error,
  formHelperTextProps
}) => {
  if (Array.isArray(error)) {
    return /*#__PURE__*/jsxRuntime.jsx(material.FormHelperText, {
      ...formHelperTextProps,
      error: true,
      children: error.map(e => e.message).filter(baseline.filterNoUndefinedNoNull).join(", ")
    });
  }
  if (error?.message) {
    return /*#__PURE__*/jsxRuntime.jsx(material.FormHelperText, {
      ...formHelperTextProps,
      error: true,
      children: error?.message
    });
  }
  return null;
};

/**
 * Wrapper around react-hook-form's useFormContext.
 *
 * Should behave like the original function, only exposing a "fieldName"
 *  function on top which is used to validate field names.
 */
const useHookFormContext = () => {
  const form = reactHookForm.useFormContext();
  return {
    ...form,
    fieldName: lodashEs.identity
  };
};

/**
 * Get the field errors for a (possibly nested) field name.
 *
 * Checking `formState.errors[fieldName]` only works if fieldName is not a path
 *  (e.g. Does not include dots).
 *
 * Did not find a built-in way to do this … there might be one though.
 */
const getFormErrorForNestedKeys = (errors, fieldName) => {
  const nestedKeys = fieldName.split(".");
  //
  // To my best knowledge, this works as expected.
  //
  // It recursively walks the error object by the given keys
  //  until the lowest level is reached, or undefined returned.
  //
  // Typescript is just not very happy with the dynamic nature of this,
  //  hence the errors.
  //
  /* eslint-disable @typescript-eslint/ban-ts-comment,@typescript-eslint/no-unsafe-return */
  // @ts-expect-error
  return nestedKeys.reduce(
  // @ts-expect-error
  (errorObj, pathKey) => errorObj?.[pathKey], errors);
  /* eslint-enable */
};

/**
 * Returns the error for a given field name.
 *
 * @throws Error when FormContext is null.
 */
const useFormFieldError = fieldName => {
  const form = useHookFormContext();
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    formState
  } = form;
  const errors = getFormErrorForNestedKeys(formState.errors, fieldName);
  return errors;
};

const FormFieldError = ({
  fieldName,
  formHelperTextProps
}) => {
  const error = useFormFieldError(fieldName);
  return /*#__PURE__*/jsxRuntime.jsx(FormFieldErrorDisplay, {
    error: error,
    formHelperTextProps: formHelperTextProps
  });
};

/**
 * Returns whether or not a field has an error.
 *
 * @throws Error when FormContext is null.
 */
const useFormFieldHasError = fieldName => !!useFormFieldError(fieldName);

/**
 * Return a function which turns our TranslatedString into a plain string.
 *
 * @throws Error if no t was provided but a translated string.
 */
const useTranslateString = () => {
  if (!i18next.t) {
    throw Error("If you pass in a translated validate function you need to provide a t");
  }
  return react.useCallback(input => {
    return typeof input === "string" ? input : input(i18next.t);
  }, []);
};

/**
 * Merge a form field with defaults.
 */
const useMergedFormField = (
/**
 * Form fields, typically those passed into a component.
 *
 */
formField, t,
/**
 * Additional defaults. Duplicate values will be overridden by the formField.
 */
formFieldDefaults) => {
  const translate = useTranslateString();
  const merged = react.useMemo(() => {
    const builtInDefaults = {
      label: baseline.uppercaseFirstLetter(formField.name),
      required: false,
      requiredErrorMessage: "Please fill in required information",
      validate: undefined
    };
    return {
      ...builtInDefaults,
      ...formFieldDefaults,
      ...formField
    };
  }, [formField, formFieldDefaults]);
  const withPlainStrings = react.useMemo(() => {
    // Translating the validate function is a bit tricky,
    //  since it can be an object in both cases.
    const validate = (() => {
      if (typeof merged.validate === "object" && typeof merged.validate.translated === "function") {
        if (!t) {
          throw Error("If you pass in a translated validate function you need to provide a t");
        }
        return merged.validate.translated(t);
      }
      return merged.validate;
    })(); // This should be fine. Not sure why TS is complaining.
    return {
      ...merged,
      label: translate(merged.label, t),
      requiredErrorMessage: translate(merged.requiredErrorMessage, t),
      validate
    };
  }, [merged, t, translate]);
  return withPlainStrings;
};

/**
 * An effect that unregisters a field from the form when the component unmounts.
 *
 * @throws Error when FormContext is null.
 */
const useEffectFieldUnregisterOnUnmount = ({
  name,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  /**
   * Default options for unregistering the field.
   *
   * Needed to wrap this in a state in order to prevent infinite rerenders.
   */
  const [options] = react.useState(unregisterOptions);
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    unregister
  } = form;
  react.useEffect(() => {
    return () => {
      if (isUnregisteringOnUnmount) {
        unregister(name, options);
      }
    };
  }, [isUnregisteringOnUnmount, name, unregister, options]);
};

var GroupLabelSorting;
(function (GroupLabelSorting) {
  GroupLabelSorting["Alphabetical"] = "alphabetical";
  GroupLabelSorting["GroupMemberCountAsc"] = "groupMemberCountAsc";
})(GroupLabelSorting || (GroupLabelSorting = {}));
/**
 * Sorts option in the desired order.
 */
const useSortedOptionsWithGroup$1 = (selectableOptions, sorting = GroupLabelSorting.Alphabetical) => {
  return react.useMemo(() => {
    if (sorting === GroupLabelSorting.GroupMemberCountAsc) {
      const groupCounts = selectableOptions.reduce((acc, option) => {
        if (option.group) {
          acc[option.group] = (acc[option.group] || 0) + 1;
        }
        return acc;
      }, {});
      return selectableOptions.sort((a, b) => {
        if (a.group == undefined && !!b.group) {
          return -1;
        }
        if (a.group && b.group) {
          const groupA = groupCounts[a.group];
          const groupB = groupCounts[b.group];
          if (groupA && groupB && groupA < groupB) {
            return -1;
          } else if (groupCounts[a.group] === groupCounts[b.group]) {
            if (b.label > a.label) {
              return -1;
            }
            return 1;
          }
          return 1;
        }
        if (b.label > a.label) {
          return -1;
        }
        return 1;
      });
    }
    return selectableOptions.sort((a, b) => {
      if (a.group == undefined && !!b.group) {
        return -1;
      }
      if (a.group && b.group && a.group < b.group) {
        return -1;
      }
      if (a.group == b.group && b.label > a.label) {
        return 1;
      }
      return 0;
    });
  }, [selectableOptions, sorting]);
};

const icon = /*#__PURE__*/jsxRuntime.jsx(iconsMaterial.CheckBoxOutlineBlank, {
  fontSize: "small"
});
const checkedIcon = /*#__PURE__*/jsxRuntime.jsx(iconsMaterial.CheckBox, {
  fontSize: "small"
});
const defaultNonMultiselectValue = "";
/**
 * Renders a MUI autocomplete input that is embedded in a react hook form context.
 *
 * @throws Error when FormContext is null.
 */
const InputAutocomplete = ({
  formField,
  selectableOptions,
  noOptions,
  autoCompleteProps,
  checkboxesForMultiselect: renderCheckboxes,
  groupSorting,
  inputTextFieldProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    register,
    control,
    setValue
  } = form;
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const multiSelect = !!autoCompleteProps?.multiple;
  const value = reactHookForm.useWatch({
    name,
    control,
    exact: true
  });
  const {
    value: valueToUse,
    hasValue
  } = react.useMemo(() => {
    if (value) {
      return {
        value,
        hasValue: true
      };
    }
    return {
      value: multiSelect ? [] : defaultNonMultiselectValue,
      hasValue: false
    };
  }, [multiSelect, value]);
  const adjustedSelectableOptions = react.useMemo(() => {
    if (hasValue || multiSelect) {
      return selectableOptions;
    }
    return [...selectableOptions, {
      value: defaultNonMultiselectValue,
      label: ""
    }];
  }, [hasValue, multiSelect, selectableOptions]);
  const sortedOptions = useSortedOptionsWithGroup$1(adjustedSelectableOptions, groupSorting);
  baseline.assertTruthy(["string", "number", "object"].includes(typeof valueToUse), `Value (Field: ${name}, value: ${valueToUse?.toString() || "undefined"}) for select input has unexpected type`);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || autoCompleteProps?.disabled;
  const props = register(name, {
    required: isRequired ? requiredErrorMessage : false,
    validate,
    disabled: isDisabled
  });
  const currentValue = react.useMemo(() => {
    return multiSelect ? adjustedSelectableOptions.filter(o => {
      if (Array.isArray(valueToUse)) {
        return valueToUse.includes(o.value);
      }
      return adjustedSelectableOptions.find(option => option.value === valueToUse);
    }) : adjustedSelectableOptions.find(option => option.value === valueToUse);
  }, [multiSelect, adjustedSelectableOptions, valueToUse]);
  const renderOption = react.useMemo(() => {
    if (autoCompleteProps?.renderOption) {
      return autoCompleteProps.renderOption;
    }
    return multiSelect && renderCheckboxes ? (liProps, option) => {
      return /*#__PURE__*/jsxRuntime.jsxs("li", {
        ...liProps,
        children: [/*#__PURE__*/jsxRuntime.jsx(material.Checkbox, {
          icon: icon,
          checkedIcon: checkedIcon,
          sx: {
            mr: 2
          },
          checked: Array.isArray(currentValue) ? !!currentValue.find(item => item.value === option.value) : false
        }), option.label]
      });
    } : undefined;
  }, [autoCompleteProps?.renderOption, currentValue, multiSelect, renderCheckboxes]);
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    required: isRequired,
    disabled: isDisabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.Autocomplete, {
      options: sortedOptions,
      value: currentValue,
      ...props,
      required: isRequired,
      label: label,
      renderOption: renderOption,
      multiple: multiSelect,
      getOptionLabel: o => {
        if (baseline.objectHasKey(o, "label")) {
          return o.label;
        }
        return "";
      },
      onChange: (e, selectedOption) => {
        if (Array.isArray(selectedOption)) {
          setValue(name, selectedOption.map(o => o.value), {
            shouldDirty: true,
            shouldValidate: true,
            shouldTouch: true
          });
        } else if (selectedOption) {
          setValue(name, selectedOption.value, {
            shouldDirty: true,
            shouldValidate: true,
            shouldTouch: true
          });
        }
      },
      noOptionsText: noOptions,
      filterOptions: options => {
        return options.filter(o => o.value !== defaultNonMultiselectValue);
      },
      renderInput: params => {
        return /*#__PURE__*/jsxRuntime.jsx(material.TextField, {
          ...params,
          label: label,
          variant: "outlined",
          ...inputTextFieldProps,
          required: isRequired,
          disabled: isDisabled,
          error: hasError
        });
      },
      groupBy: option => option.group || "Choose"
      // need to parse this as any in order to get no typing errors
      // for multiselect
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      ,
      ...autoCompleteProps
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputCheckbox = ({
  formField,
  jsxLabel,
  checkboxProps,
  formControlLabelProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control,
    setValue
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const id = `hook-form-input-checkbox-${name}`;
  const disabled = muiFormControl?.disabled || checkboxProps?.disabled;
  const isRequired = required || muiFormControl?.required;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    disabled: disabled,
    required: required,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.FormControlLabel, {
      required: jsxLabel ? false : isRequired // If jsxLabel is set, we don't want to show the asterisk.
      ,
      disabled: disabled,
      label: jsxLabel ?? label,
      sx: {
        color: t => hasError ? t.palette.error.main : undefined
      },
      control: /*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
        name: name,
        control: control,
        rules: {
          required: isRequired ? requiredErrorMessage : false,
          validate
        },
        render: ({
          field: {
            value
          }
        }) => {
          return /*#__PURE__*/jsxRuntime.jsx(material.Checkbox, {
            checked: !!value,
            "aria-labelledby": id,
            onChange: (e, val) => {
              setValue(name, val, {
                shouldValidate: true,
                shouldDirty: true,
                shouldTouch: true
              });
            },
            ...checkboxProps,
            disabled: disabled
          });
        }
      }),
      ...formControlLabelProps
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputDatePicker = ({
  formField,
  datePickerProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const [date, setDate] = react.useState(dayjs());
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || datePickerProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsx(material.Box, {
    children: /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
      error: hasError,
      required: isRequired,
      disabled: isDisabled,
      children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
        name: name,
        defaultValue: date,
        control: control,
        rules: {
          required: isRequired ? requiredErrorMessage : false
        },
        render: ({
          field: {
            onChange,
            ...restField
          }
        }) => /*#__PURE__*/jsxRuntime.jsx(xDatePickers.DatePicker, {
          label: label,
          onChange: event => {
            onChange(event);
            if (event) {
              setDate(event);
            }
          },
          disabled: isDisabled,
          slotProps: {
            textField: {
              required: isRequired,
              disabled: isDisabled,
              error: hasError
            }
          },
          ...restField,
          ...datePickerProps
        })
      }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
        fieldName: formField.name
      })]
    })
  });
};

const InputDateTimePicker = ({
  formField,
  dateTimePickerProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const [date, setDate] = react.useState(dayjs());
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || dateTimePickerProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsx(material.Box, {
    children: /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
      error: hasError,
      required: isRequired,
      disabled: isDisabled,
      children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
        name: name,
        defaultValue: date,
        control: control,
        rules: {
          required: isRequired ? requiredErrorMessage : false
        },
        render: ({
          field: {
            onChange,
            ...restField
          }
        }) => /*#__PURE__*/jsxRuntime.jsx(xDatePickers.DateTimePicker, {
          label: label,
          ampm: dateTimePickerProps?.ampm ? dateTimePickerProps.ampm : false,
          onChange: event => {
            onChange(event);
            if (event) {
              setDate(event);
            }
          },
          disabled: isDisabled,
          required: isRequired,
          slotProps: {
            textField: {
              required: isRequired,
              disabled: isDisabled,
              error: hasError
            }
          },
          ...restField,
          ...dateTimePickerProps
        })
      }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
        fieldName: formField.name
      })]
    })
  });
};

const InputNumber = ({
  formField,
  textFieldProps,
  numericFormatProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  const {
    control
  } = form;
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  if (!form) {
    throw Error(formContextNull);
  }
  const hasError = useFormFieldHasError(formField.name);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || textFieldProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    required: required,
    disabled: isDisabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: props => {
        const {
          ref,
          ...rest
        } = props.field;
        return (
          /*#__PURE__*/
          // @ts-expect-error TextFieldProps is not compatible with NumberFormatBaseProps
          jsxRuntime.jsx(reactNumberFormat.NumericFormat, {
            ...rest,
            customInput: material.TextField,
            onValueChange: target => {
              rest.onChange(target.value);
            },
            label: label,
            onChange: undefined,
            onBlur: props.field.onBlur,
            error: !!props.fieldState.error,
            ...textFieldProps,
            ...numericFormatProps,
            disabled: isDisabled,
            required: isRequired
          })
        );
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputOutlinedInput = ({
  formField,
  outlinedInputProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    control
  } = form;
  const hasError = useFormFieldHasError(formField.name);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || outlinedInputProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    required: required,
    disabled: muiFormControl?.disabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.InputLabel, {
      required: isRequired,
      disabled: isDisabled,
      children: label
    }), /*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: ({
        field: {
          value,
          onBlur,
          onChange
        }
      }) => {
        return /*#__PURE__*/jsxRuntime.jsx(material.OutlinedInput, {
          value: value,
          onChange: onChange,
          onBlur: onBlur,
          label: label,
          ...outlinedInputProps,
          required: isRequired,
          disabled: isDisabled
        });
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputRadio = ({
  formField,
  selectableOptions,
  formControlLabelProps,
  radioGroupProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const id = `hook-form-input-radio-${name}`;
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || formControlLabelProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    disabled: muiFormControl?.disabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.FormLabel, {
      id: id,
      required: isRequired,
      disabled: isDisabled,
      error: hasError,
      sx: {
        color: t => hasError ? t.palette.error.main : undefined
      },
      children: label
    }), /*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: ({
        field: {
          onChange,
          value,
          onBlur
        }
      }) => {
        return /*#__PURE__*/jsxRuntime.jsx(material.RadioGroup, {
          value: value,
          "aria-labelledby": id,
          onChange: onChange,
          onBlur: onBlur,
          ...radioGroupProps,
          children: selectableOptions?.map(option => {
            return /*#__PURE__*/jsxRuntime.jsx(material.FormControlLabel, {
              value: option.value,
              control: /*#__PURE__*/jsxRuntime.jsx(material.Radio, {}),
              label: option.label,
              ...formControlLabelProps,
              disabled: isDisabled
            }, typeof option.value === "boolean" ? option.value.toString() : option.value);
          })
        });
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

/**
 * Sorts the options by group and value.
 */
const useSortedOptionsWithGroup = selectableOptions => {
  return react.useMemo(() => selectableOptions.sort((a, b) => {
    if (a.group == undefined && !!b.group) {
      return -1;
    }
    if (a.group && b.group && a.group < b.group) {
      return -1;
    }
    if (a.group == b.group && b.value > a.value) {
      return 1;
    }
    return 0;
  }), [selectableOptions]);
};

const InputSelect = ({
  formField,
  selectableOptions,
  optionsTitle,
  selectComponentProps,
  tooltipHolder,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    control
  } = form;
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const defaultValue = react.useMemo(() => selectComponentProps?.multiple ? [] : "", [selectComponentProps?.multiple]);
  const id = `input-select-${name}`;
  const adjustedOptions = react.useMemo(() => selectComponentProps?.multiple || Array.isArray(defaultValue) ? selectableOptions : [...selectableOptions, {
    value: defaultValue,
    label: ""
  }], [defaultValue, selectComponentProps?.multiple, selectableOptions]);
  const sortedOptions = useSortedOptionsWithGroup(adjustedOptions);
  const hasErrors = useFormFieldHasError(formField.name);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || selectComponentProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasErrors,
    required: isRequired,
    disabled: isDisabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.InputLabel, {
      id: id,
      required: isRequired,
      disabled: isDisabled,
      error: hasErrors,
      children: label
    }), /*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: ({
        field: {
          onChange,
          onBlur,
          value
        },
        fieldState: {
          error
        }
      }) => {
        const valueToUse = value || defaultValue;
        return /*#__PURE__*/jsxRuntime.jsxs(material.Select, {
          labelId: id,
          ...selectComponentProps,
          label: label,
          value: valueToUse,
          error: !!error,
          onChange: onChange,
          onBlur: onBlur,
          disabled: isDisabled,
          required: isRequired,
          children: [optionsTitle && /*#__PURE__*/jsxRuntime.jsx(material.MenuItem, {
            value: defaultValue,
            disabled: true,
            children: /*#__PURE__*/jsxRuntime.jsx("em", {
              children: optionsTitle
            })
          }), sortedOptions?.filter(o => o.value !== "").map((option, index) => {
            const optionBefore = sortedOptions[index - 1];
            const showGroup = (optionBefore || index == 0) && option.group && optionBefore?.group !== option.group;
            const disabledText = typeof option.disabled === "string" ? option.disabled : undefined;
            const isDisabledToUse = !!disabledText || !!option.disabled || isDisabled;
            const menuItem = /*#__PURE__*/jsxRuntime.jsx(material.MenuItem, {
              value: typeof option.value === "boolean" ? option.value.toString() : option.value,
              disabled: isDisabledToUse,
              title: typeof option.disabled === "string" ? option.disabled : undefined,
              selected: typeof option.value === "boolean" ? option.value.toString() === value : value === option.value,
              children: option.label
            }, option.label);
            const wrappedMenuItem = disabledText ? /*#__PURE__*/jsxRuntime.jsxs(material.Box, {
              sx: {
                position: "relative"
              },
              children: [menuItem, /*#__PURE__*/jsxRuntime.jsx(material.Stack, {
                direction: "column",
                justifyContent: "center",
                spacing: 1,
                sx: {
                  position: "absolute",
                  right: th => th.spacing(0.5),
                  top: 0,
                  bottom: 0
                },
                children: tooltipHolder ? /*#__PURE__*/jsxRuntime.jsx(material.Tooltip, {
                  title: disabledText,
                  children: tooltipHolder
                }) : null
              })]
            }) : menuItem;
            return showGroup ? [/*#__PURE__*/jsxRuntime.jsx(material.ListSubheader, {
              children: option.group
            }, option.group), wrappedMenuItem] : wrappedMenuItem;
          })]
        });
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputSelectFromEnum = props => {
  const {
    enumData,
    formField
  } = props;
  const translateFunction = formField.t;
  const options = react.useMemo(() => {
    return Object.entries(enumData.enumToUse).map(([key, value]) => {
      const label = enumData.labelsForEnum[key];
      baseline.assertTruthy(label, "Could not find a label for value: " + value + " in Field " + formField.name);
      if (typeof label === "string") {
        return {
          label,
          value
        };
      }
      baseline.assertTruthy(translateFunction, `If you want to use translated labels for field (name: ${formField.name}) you need to provide a translate function in the HookFormProvider.`);
      return {
        label: label(translateFunction),
        value
      };
    });
  }, [enumData.enumToUse, enumData.labelsForEnum, formField.name, translateFunction]);
  return /*#__PURE__*/jsxRuntime.jsx(InputSelect, {
    ...props,
    selectableOptions: options,
    formField: formField
  });
};

const InputSlider = ({
  formField,
  sliderProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  if (!form) {
    throw Error(formContextNull);
  }
  const {
    control
  } = form;
  const hasError = useFormFieldHasError(formField.name);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || sliderProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    required: isRequired,
    disabled: isDisabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      defaultValue: 0,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: ({
        field: {
          onChange,
          value,
          onBlur
        }
      }) => {
        return /*#__PURE__*/jsxRuntime.jsx(material.Slider, {
          value: value || 0,
          onChange: onChange,
          onBlur: onBlur,
          required: isRequired,
          label: label,
          component: sliderProps?.component || "span",
          max: typeof sliderProps?.max === "number" ? sliderProps.max : undefined,
          min: typeof sliderProps?.min === "number" ? sliderProps.min : undefined,
          ...sliderProps,
          disabled: isDisabled
        });
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: name
    })]
  });
};

const InputSwitch = ({
  formField,
  switchProps,
  formControlLabelProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control,
    setValue
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || switchProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    disabled: isDisabled,
    required: isRequired,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.FormControlLabel, {
      label: formField.label,
      disabled: isDisabled,
      required: isRequired,
      sx: {
        color: t => hasError ? t.palette.error.main : undefined
      },
      control: /*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
        name: name,
        control: control,
        rules: {
          required: isRequired ? requiredErrorMessage : false,
          validate
        },
        render: ({
          field: {
            value
          }
        }) => {
          return /*#__PURE__*/jsxRuntime.jsx(material.Switch, {
            checked: !!value,
            onChange: (e, val) => {
              setValue(name, val, {
                shouldValidate: true,
                shouldDirty: true,
                shouldTouch: true
              });
            },
            ...switchProps
          });
        }
      }),
      ...formControlLabelProps
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputTextField = ({
  formField,
  textFieldProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const form = useHookFormContext();
  const {
    control
  } = form;
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField, formField.t);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  if (!form) {
    throw Error(formContextNull);
  }
  const hasError = useFormFieldHasError(formField.name);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || textFieldProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    required: isRequired,
    disabled: isDisabled,
    children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
      name: name,
      control: control,
      rules: {
        required: isRequired ? requiredErrorMessage : false,
        validate
      },
      render: ({
        field: {
          onChange,
          value
        },
        fieldState: {
          error
        }
      }) => {
        return /*#__PURE__*/jsxRuntime.jsx(material.TextField, {
          error: !!error,
          onChange: onChange,
          value: value,
          label: label,
          ...textFieldProps,
          required: isRequired,
          disabled: isDisabled
        });
      }
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

// eslint-disable-next-line @typescript-eslint/no-unused-vars
const InputTimePicker = ({
  formField,
  timePickerProps,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    control
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    label,
    name,
    required,
    requiredErrorMessage
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const [date, setDate] = react.useState(dayjs());
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || timePickerProps?.disabled;
  return /*#__PURE__*/jsxRuntime.jsx(material.Box, {
    children: /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
      error: hasError,
      required: isRequired,
      disabled: isDisabled,
      children: [/*#__PURE__*/jsxRuntime.jsx(reactHookForm.Controller, {
        name: name,
        defaultValue: date,
        control: control,
        rules: {
          required: isRequired ? requiredErrorMessage : false
        },
        render: ({
          field: {
            onChange,
            ...restField
          }
        }) => /*#__PURE__*/jsxRuntime.jsx(xDatePickers.TimePicker, {
          label: label,
          onChange: event => {
            onChange(event);
            if (event) {
              setDate(event);
            }
          },
          disabled: isDisabled,
          required: isRequired,
          slotProps: {
            textField: {
              required: isRequired,
              disabled: isDisabled,
              error: hasError
            }
          },
          ...restField,
          ...timePickerProps
        })
      }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
        fieldName: formField.name
      })]
    })
  });
};

const InputToggleButton = ({
  formField,
  toggleButtonProps,
  formControlLabelProps,
  children,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    register,
    control,
    setValue
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const id = `hook-form-input-toggle-button-${name}`;
  const valueToUse = !!reactHookForm.useWatch({
    name: name,
    control: control,
    exact: true
  });
  baseline.assertTruthy(typeof valueToUse === "boolean", `Value (Field: ${name}, value: ${valueToUse?.toString() || "undefined"}) for a InputToggleButton should be undefined or boolean`);
  const onClick = react.useCallback(
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  e => {
    setValue(name, !valueToUse, {
      shouldValidate: true,
      shouldDirty: true,
      shouldTouch: true
    });
  }, [name, setValue, valueToUse]);
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || toggleButtonProps?.disabled;
  const registered = register(name, {
    required: isRequired ? requiredErrorMessage : false,
    validate,
    disabled: muiFormControl?.disabled
  });
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    disabled: isDisabled,
    required: isRequired,
    children: [/*#__PURE__*/jsxRuntime.jsx(material.FormControlLabel, {
      required: isRequired,
      label: formField.label,
      labelPlacement: "top",
      disabled: isDisabled,
      control: /*#__PURE__*/jsxRuntime.jsx(material.ToggleButton, {
        value: valueToUse,
        selected: valueToUse,
        "aria-labelledby": id,
        onClick: onClick,
        ...registered,
        ...toggleButtonProps,
        children: children
      }),
      sx: {
        alignItems: "flex-start",
        ml: 0,
        color: t => hasError ? t.palette.error.main : undefined,
        ...formControlLabelProps?.sx
      },
      ...formControlLabelProps
    }), /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

const InputToggleButtonGroup = ({
  formField,
  toggleButtonGroupProps,
  stackProps,
  typographyProps,
  buttons,
  enforceValueSelected = false,
  unregisterOptions,
  isUnregisteringOnUnmount
}) => {
  const {
    register,
    setValue,
    control
  } = useHookFormContext();
  const hasError = useFormFieldHasError(formField.name);
  const muiFormControl = material.useFormControl();
  const {
    name,
    required,
    requiredErrorMessage,
    validate
  } = useMergedFormField(formField);
  useEffectFieldUnregisterOnUnmount({
    name,
    unregisterOptions,
    isUnregisteringOnUnmount
  });
  const changeEv = react.useCallback((_, value) => {
    const onSetValue = () => setValue(name, value, {
      shouldValidate: true,
      shouldDirty: true,
      shouldTouch: true
    });
    if (enforceValueSelected) {
      if (toggleButtonGroupProps?.exclusive === true && value !== null) {
        onSetValue();
      } else if (toggleButtonGroupProps?.exclusive === false || toggleButtonGroupProps?.exclusive === undefined && value?.length) {
        onSetValue();
      }
    } else {
      onSetValue();
    }
  }, [enforceValueSelected, name, setValue, toggleButtonGroupProps?.exclusive]);
  const id = `hook-form-input-toggle-button-group-${name}`;
  const registered = register(name, {
    required: required ? requiredErrorMessage : false,
    validate,
    disabled: muiFormControl?.disabled
  });
  // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
  const valueFromForm = reactHookForm.useWatch({
    name: name,
    control: control,
    exact: true
  });
  const isRequired = required || muiFormControl?.required;
  const isDisabled = muiFormControl?.disabled || toggleButtonGroupProps?.disabled;
  const toggleButtonGroup = /*#__PURE__*/jsxRuntime.jsx(material.ToggleButtonGroup, {
    ...registered,
    ...toggleButtonGroupProps,
    onChange: changeEv
    // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
    ,
    value: valueFromForm,
    children: buttons.map((button, i) => /*#__PURE__*/jsxRuntime.jsx(material.ToggleButton
    // eslint-disable-next-line react/no-array-index-key
    , {
      value: button.value,
      "aria-labelledby": id,
      ...button.toggleButtonProps,
      disabled: isDisabled,
      children: button.icon
    }, `${button.value.toString()}-${i}`))
  });
  const label = /*#__PURE__*/jsxRuntime.jsx(material.Typography, {
    component: "span",
    ...typographyProps,
    sx: {
      color: t => {
        if (hasError) {
          return t.palette.error.main;
        }
        return isDisabled ? t.palette.text.disabled : undefined;
      }
    },
    children: formField.label
  });
  return /*#__PURE__*/jsxRuntime.jsxs(material.FormControl, {
    error: hasError,
    disabled: isDisabled,
    required: isRequired,
    children: [formField.label ? /*#__PURE__*/jsxRuntime.jsxs(material.Stack, {
      ...stackProps,
      children: [isRequired ? /*#__PURE__*/jsxRuntime.jsxs(material.Stack, {
        id: id,
        component: "label",
        sx: {
          display: "block"
        },
        children: [label, /*#__PURE__*/jsxRuntime.jsxs(material.Box, {
          component: "span",
          "aria-hidden": true,
          sx: {
            color: hasError ? t => t.palette.error.main : undefined
          },
          children: ["\u2009", "*"]
        })]
      }) : label, toggleButtonGroup]
    }) : toggleButtonGroup, /*#__PURE__*/jsxRuntime.jsx(FormFieldError, {
      fieldName: formField.name
    })]
  });
};

/**
 * Turn an async submitHandler into a synchronous one.
 *
 * Reasoning:
 * - we're often talking to the API during form submission. The onSubmit handler will be returning a Promise in this case.
 * - the `form` element, per definition, always expects a synchronous function.
 * - creating on inline function in every form is a bit clumsy, and does not look clean.
 *
 * Then/catch cases should be properly handled by the submit handler itself,
 *  the catch supplied here is only a last safety net against an "unhandled promise rejection" error.
 */
const syncSubmit = asyncSubmitHandler => {
  return e => {
    asyncSubmitHandler(e).catch(baseline.rethrow);
  };
};

/**
 * Wrapper around react-hook-form's useForm.
 *
 * Should behave like the original function, only exposing a "fieldName"
 *  function on top which is used to validate field names.
 */
const useHookForm = props => {
  const form = reactHookForm.useForm(props);
  return {
    ...form,
    fieldName: lodashEs.identity
  };
};
const useHookFormFieldArray = reactHookForm.useFieldArray;

/**
 * Reexport of FormProvider.
 *
 * This became necessary as context is not available when the FormProvider is initialized outside of the package. Most likely this is some kind of instance mismatch.
 */
const HookFormProvider = reactHookForm.FormProvider;

const InputEmail = props => {
  const merged = useMergedFormField(props.formField, props.formField.t, formDefaults);
  const commonProps = react.useMemo(() => ({
    textFieldProps: {
      type: "email",
      autoComplete: "email",
      ...props.textFieldProps
    },
    formField: merged
  }), [merged, props.textFieldProps]);
  return props.isUnregisteringOnUnmount ? /*#__PURE__*/jsxRuntime.jsx(InputTextField, {
    ...commonProps,
    isUnregisteringOnUnmount: props.isUnregisteringOnUnmount,
    unregisterOptions: props.unregisterOptions
  }) : /*#__PURE__*/jsxRuntime.jsx(InputTextField, {
    ...commonProps,
    isUnregisteringOnUnmount: props.isUnregisteringOnUnmount
  });
};
const formDefaults = {
  required: true,
  validate: emailInput => {
    if (emailInput && emailInput.match(/.@./)) {
      return true;
    }
    return "E-Mail address invalid";
  }
};

const InputPasswordSet = ({
  passwordField,
  passwordValidationField,
  doNotMatchError,
  passwordValidationTextFieldProps,
  passwordTextFieldProps
}) => {
  const {
    watch
  } = useHookFormContext();
  const passwordFieldMerged = useMergedFormField(passwordField, passwordField.t, {
    required: true
  });
  const validationFieldMerged = useMergedFormField(passwordValidationField, passwordValidationField.t, {
    required: true
  });
  const validatePasswordMatch = react.useCallback(value => {
    const passwordValue = watch(passwordFieldMerged.name);
    return value === passwordValue || doNotMatchError;
  }, [doNotMatchError, passwordFieldMerged.name, watch]);
  return /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
    children: [/*#__PURE__*/jsxRuntime.jsx(InputTextField, {
      formField: passwordFieldMerged,
      textFieldProps: {
        type: "password",
        autoComplete: "new-password",
        ...passwordTextFieldProps
      }
    }), /*#__PURE__*/jsxRuntime.jsx(InputTextField, {
      formField: {
        ...validationFieldMerged,
        validate: validatePasswordMatch,
        t: passwordValidationField.t
      },
      textFieldProps: {
        type: "password",
        autoComplete: "new-password",
        ...passwordValidationTextFieldProps
      }
    })]
  });
};

exports.LoadingButtonState = void 0;
(function (LoadingButtonState) {
  LoadingButtonState["Idle"] = "idle";
  LoadingButtonState["Loading"] = "loading";
  LoadingButtonState["Success"] = "success";
})(exports.LoadingButtonState || (exports.LoadingButtonState = {}));

const LoadingButton = ({
  buttonText,
  buttonTextSuccess,
  loadingButtonProps,
  loadingButtonPropsPropsSuccess,
  buttonState,
  successIcon
}) => {
  const isSuccess = buttonState === exports.LoadingButtonState.Success;
  const propsToSpread = isSuccess ? loadingButtonPropsPropsSuccess : loadingButtonProps;
  return /*#__PURE__*/jsxRuntime.jsx(lab.LoadingButton, {
    loading: buttonState === exports.LoadingButtonState.Loading,
    disabled: buttonState !== exports.LoadingButtonState.Idle,
    ...propsToSpread,
    children: buttonState === exports.LoadingButtonState.Success ? /*#__PURE__*/jsxRuntime.jsxs(jsxRuntime.Fragment, {
      children: [successIcon ? successIcon : null, buttonTextSuccess ? buttonTextSuccess : buttonText]
    }) : buttonText
  });
};

/**
 * Get loading button state from react-query mutation status.
 */
const loadingButtonStateFromReactQueryMutationStatus = mutationStatus => {
  const mapStatus = {
    idle: exports.LoadingButtonState.Idle,
    error: exports.LoadingButtonState.Idle,
    success: exports.LoadingButtonState.Success,
    loading: exports.LoadingButtonState.Loading
  };
  return mapStatus[mutationStatus];
};
/**
 * Get loading button state from a react-hook-form context.
 */
const useLoadingButtonStateFromFormContext = () => {
  const formContext = useHookFormContext();
  return loadingButtonStateFromFormState(formContext.formState);
};
/**
 * Get loading button state from a react-hook-form state.
 */
const loadingButtonStateFromFormState = (
// we are not interested in the value types FormState holds
// eslint-disable-next-line @typescript-eslint/no-explicit-any
formState) => {
  if (formState.isSubmitting) {
    return exports.LoadingButtonState.Loading;
  }
  if (formState.isDirty) {
    return exports.LoadingButtonState.Idle;
  }
  if (formState.isSubmitSuccessful) {
    return exports.LoadingButtonState.Success;
  }
  return exports.LoadingButtonState.Idle;
};

exports.FormFieldError = FormFieldError;
exports.FormFieldErrorDisplay = FormFieldErrorDisplay;
exports.HookFormProvider = HookFormProvider;
exports.InputAutocomplete = InputAutocomplete;
exports.InputCheckbox = InputCheckbox;
exports.InputDatePicker = InputDatePicker;
exports.InputDateTimePicker = InputDateTimePicker;
exports.InputEmail = InputEmail;
exports.InputNumber = InputNumber;
exports.InputOutlinedInput = InputOutlinedInput;
exports.InputPasswordSet = InputPasswordSet;
exports.InputRadio = InputRadio;
exports.InputSelect = InputSelect;
exports.InputSelectFromEnum = InputSelectFromEnum;
exports.InputSlider = InputSlider;
exports.InputSwitch = InputSwitch;
exports.InputText = InputOutlinedInput;
exports.InputTextField = InputTextField;
exports.InputTimePicker = InputTimePicker;
exports.InputToggleButton = InputToggleButton;
exports.InputToggleButtonGroup = InputToggleButtonGroup;
exports.LoadingButton = LoadingButton;
exports.getFormErrorForNestedKeys = getFormErrorForNestedKeys;
exports.loadingButtonStateFromFormState = loadingButtonStateFromFormState;
exports.loadingButtonStateFromReactQueryMutationStatus = loadingButtonStateFromReactQueryMutationStatus;
exports.syncSubmit = syncSubmit;
exports.useFormFieldError = useFormFieldError;
exports.useFormFieldHasError = useFormFieldHasError;
exports.useHookForm = useHookForm;
exports.useHookFormContext = useHookFormContext;
exports.useHookFormFieldArray = useHookFormFieldArray;
exports.useLoadingButtonStateFromFormContext = useLoadingButtonStateFromFormContext;
exports.useMergedFormField = useMergedFormField;
exports.useSortedOptionsWithGroup = useSortedOptionsWithGroup;
exports.useTranslateString = useTranslateString;
//# sourceMappingURL=packageExports.js.map
